@@ -1,7 +1,7 @@
 /*
- *  This file is part of poEdit (http://www.poedit.org)
+ *  This file is part of poEdit (http://www.poedit.net)
  *
- *  Copyright (C) 1999-2006 Vaclav Slavik
+ *  Copyright (C) 1999-2007 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE. 
  *
- *  $Id: catalog.cpp 1047 2006-10-08 18:37:53Z vaclavslavik $
+ *  $Id: catalog.cpp 1116 2007-06-16 20:56:34Z vaclavslavik $
  *
  *  Translations catalog
  *
@@ -60,29 +60,18 @@ WX_DEFINE_OBJARRAY(CatalogDeletedDataArray)
 
 
 // Read one line from file, remove all \r and \n characters, ignore empty lines
-static wxString ReadTextLine(wxTextFile* f, wxMBConv *conv)
+static wxString ReadTextLine(wxTextFile* f)
 {
     wxString s;
 
-    while (s.IsEmpty())
+    while (s.empty())
     {
         if (f->Eof()) return wxEmptyString;
 
         // read next line and strip insignificant whitespace from it:
         s = f->GetNextLine().Strip(wxString::both);
     }
-#if !wxUSE_UNICODE
-    if (conv)
-    {
-        wxString s2 = wxString(s.wc_str(*conv), wxConvUTF8);
-        if (s2.empty() && !s.empty())
-        {
-            wxLogError(_("Error while loading file '%s': line %u is corrupted."),
-                       f->GetName(), f->GetCurrentLine());
-        }
-        return s2;
-    }
-#endif
+
     return s;
 }
 
@@ -114,7 +103,6 @@ static bool ReadParamIfNotSet(const wxString& input,
 }
 
 
-#if wxUSE_UNICODE
 // Checks if the file was loaded correctly, i.e. that non-empty lines
 // ended up non-empty in memory, after doing charset conversion in
 // wxTextFile. This detects for example files that claim they are in UTF-8
@@ -150,7 +138,6 @@ bool VerifyFileCharset(const wxTextFile& f, const wxString& filename,
 
     return ok;
 }
-#endif
 
 
 // converts \n into newline character and \\ into \:
@@ -167,7 +154,7 @@ static wxString UnescapeCEscapes(const wxString& str)
     {
         if (str[i] == _T('\\'))
         {
-            switch (str[i+1])
+            switch ((wxChar)str[i+1])
             {
                 case _T('n'):
                     out << _T('\n');
@@ -274,7 +261,7 @@ void Catalog::HeaderData::UpdateDict()
     SetHeaderNotEmpty(_T("X-Poedit-Country"), Country);
     SetHeaderNotEmpty(_T("X-Poedit-SourceCharset"), SourceCodeCharset);
 
-    if (!Keywords.IsEmpty())
+    if (!Keywords.empty())
     {
         wxString kw;
         for (size_t i = 0; i < Keywords.GetCount(); i++)
@@ -520,28 +507,28 @@ bool CatalogParser::Parse()
     unsigned mlinenum;
 
     line = m_textFile->GetFirstLine();
-    if (line.IsEmpty()) line = ReadTextLine(m_textFile, m_conv);
+    if (line.empty()) line = ReadTextLine(m_textFile);
 
-    while (!line.IsEmpty())
+    while (!line.empty())
     {
         // ignore empty special tags (except for automatic comments which we
         // DO want to preserve):
         while (line == _T("#,") || line == _T("#:"))
-            line = ReadTextLine(m_textFile, m_conv);
+            line = ReadTextLine(m_textFile);
 
         // flags:
         // Can't we have more than one flag, now only the last is kept ...
         if (ReadParam(line, _T("#, "), dummy))
         {
             mflags = _T("#, ") + dummy;
-            line = ReadTextLine(m_textFile, m_conv);
+            line = ReadTextLine(m_textFile);
         }
 
         // auto comments:
         if (ReadParam(line, _T("#. "), dummy) || ReadParam(line, _T("#."), dummy)) // second one to account for empty auto comments
         {
             mautocomments.Add(dummy);
-            line = ReadTextLine(m_textFile, m_conv);
+            line = ReadTextLine(m_textFile);
         }
 
         // references:
@@ -561,7 +548,7 @@ bool CatalogParser::Parse()
                 dummy = dummy.Mid(i).Strip(wxString::both);
             }
 
-            line = ReadTextLine(m_textFile, m_conv);
+            line = ReadTextLine(m_textFile);
         }
 
         // msgid:
@@ -570,7 +557,7 @@ bool CatalogParser::Parse()
         {
             mstr = dummy.RemoveLast();
             mlinenum = m_textFile->GetCurrentLine() + 1;
-            while (!(line = ReadTextLine(m_textFile, m_conv)).IsEmpty())
+            while (!(line = ReadTextLine(m_textFile)).empty())
             {
                 if (line[0u] == _T('\t'))
                     line.Remove(0, 1);
@@ -588,7 +575,7 @@ bool CatalogParser::Parse()
             msgid_plural = dummy.RemoveLast();
             has_plural = true;
             mlinenum = m_textFile->GetCurrentLine() + 1;
-            while (!(line = ReadTextLine(m_textFile, m_conv)).IsEmpty())
+            while (!(line = ReadTextLine(m_textFile)).empty())
             {
                 if (line[0u] == _T('\t'))
                     line.Remove(0, 1);
@@ -610,7 +597,7 @@ bool CatalogParser::Parse()
             }
 
             wxString str = dummy.RemoveLast();
-            while (!(line = ReadTextLine(m_textFile, m_conv)).IsEmpty())
+            while (!(line = ReadTextLine(m_textFile)).empty())
             {
                 if (line[0u] == _T('\t'))
                     line.Remove(0, 1);
@@ -652,7 +639,7 @@ bool CatalogParser::Parse()
             {
                 wxString str = dummy.RemoveLast();
 
-                while (!(line=ReadTextLine(m_textFile, m_conv)).IsEmpty())
+                while (!(line=ReadTextLine(m_textFile)).empty())
                 {
                     if (line[0u] == _T('\t'))
                         line.Remove(0, 1);
@@ -691,7 +678,7 @@ bool CatalogParser::Parse()
             wxArrayString deletedLines;
             deletedLines.Add(line);
             mlinenum = m_textFile->GetCurrentLine() + 1;
-            while (!(line = ReadTextLine(m_textFile, m_conv)).IsEmpty())
+            while (!(line = ReadTextLine(m_textFile)).empty())
             {
                 // if line does not start with "#~ " anymore, stop reading
                 if (!ReadParam(line, _T("#~ "), dummy))
@@ -717,21 +704,21 @@ bool CatalogParser::Parse()
         {
             bool readNewLine = false;
 
-            while (!line.IsEmpty() &&
+            while (!line.empty() &&
                     line[0u] == _T('#') &&
                    (line.Length() < 2 || (line[1u] != _T(',') && line[1u] != _T(':') && line[1u] != _T('.') )))
             {
                 mcomment << line << _T('\n');
                 readNewLine = true;
-                line = ReadTextLine(m_textFile, m_conv);
+                line = ReadTextLine(m_textFile);
             }
 
             if (!readNewLine)
-                line = ReadTextLine(m_textFile, m_conv);
+                line = ReadTextLine(m_textFile);
         }
 
         else
-            line = ReadTextLine(m_textFile, m_conv);
+            line = ReadTextLine(m_textFile);
     }
 
     return true;
@@ -742,8 +729,8 @@ bool CatalogParser::Parse()
 class CharsetInfoFinder : public CatalogParser
 {
     public:
-        CharsetInfoFinder(wxTextFile *f, wxMBConv *conv)
-                : CatalogParser(f, conv), m_charset(_T("iso-8859-1")) {}
+        CharsetInfoFinder(wxTextFile *f)
+                : CatalogParser(f), m_charset(_T("iso-8859-1")) {}
         wxString GetCharset() const { return m_charset; }
 
     protected:
@@ -771,7 +758,7 @@ bool CharsetInfoFinder::OnEntry(const wxString& msgid,
                                 const wxArrayString& autocomments,
                                 unsigned lineNumber)
 {
-    if (msgid.IsEmpty())
+    if (msgid.empty())
     {
         // gettext header:
         Catalog::HeaderData hdr;
@@ -789,8 +776,8 @@ bool CharsetInfoFinder::OnEntry(const wxString& msgid,
 class LoadParser : public CatalogParser
 {
     public:
-        LoadParser(Catalog *c, wxTextFile *f, wxMBConv *conv)
-              : CatalogParser(f, conv), m_catalog(c) {}
+        LoadParser(Catalog *c, wxTextFile *f)
+              : CatalogParser(f), m_catalog(c) {}
 
     protected:
         Catalog *m_catalog;
@@ -824,7 +811,7 @@ bool LoadParser::OnEntry(const wxString& msgid,
                          const wxArrayString& autocomments,
                          unsigned lineNumber)
 {
-    if (msgid.IsEmpty())
+    if (msgid.empty())
     {
         // gettext header:
         m_catalog->m_header.FromString(mtranslations[0]);
@@ -833,7 +820,7 @@ bool LoadParser::OnEntry(const wxString& msgid,
     else
     {
         CatalogData *d = new CatalogData(wxEmptyString, wxEmptyString);
-        if (!flags.IsEmpty()) d->SetFlags(flags);
+        if (!flags.empty()) d->SetFlags(flags);
         d->SetString(msgid);
         if (has_plural)
             d->SetPluralString(msgid_plural);
@@ -857,7 +844,7 @@ bool LoadParser::OnDeletedEntry(const wxArrayString& deletedLines,
                                 unsigned lineNumber)
 {
     CatalogDeletedData *d = new CatalogDeletedData(wxArrayString());
-    if (!flags.IsEmpty()) d->SetFlags(flags);
+    if (!flags.empty()) d->SetFlags(flags);
     d->SetDeletedLines(deletedLines);
     d->SetComment(comment);
     d->SetLineNumber(lineNumber);
@@ -960,7 +947,7 @@ bool Catalog::Load(const wxString& po_file)
     if (!f.Open(po_file, wxConvISO8859_1))
         return false;
 
-    CharsetInfoFinder charsetFinder(&f, &wxConvISO8859_1);
+    CharsetInfoFinder charsetFinder(&f);
     charsetFinder.Parse();
     m_header.Charset = charsetFinder.GetCharset();
 
@@ -969,14 +956,12 @@ bool Catalog::Load(const wxString& po_file)
     if (!f.Open(po_file, encConv))
         return false;
 
-#if wxUSE_UNICODE
     if (!VerifyFileCharset(f, po_file, m_header.Charset))
     {
         wxLogError(_("There were errors when loading the catalog. Some data may be missing or corrupted as the result."));
     }
-#endif
 
-    LoadParser parser(this, &f, &encConv);
+    LoadParser parser(this, &f);
     if (!parser.Parse())
     {
         wxLogError(
@@ -1007,33 +992,33 @@ bool Catalog::Load(const wxString& po_file)
             .po file's header as X-Poedit-Foo) */
 
     if (wxFileExists(po_file + _T(".poedit")) &&
-        f.Open(po_file + _T(".poedit")))
+        f.Open(po_file + _T(".poedit"), wxConvISO8859_1))
     {
         wxString dummy;
         // poedit header (optional, we should be able to read any catalog):
         f.GetFirstLine();
-        if (ReadParam(ReadTextLine(&f, NULL),
+        if (ReadParam(ReadTextLine(&f),
                       _T("#. Number of items: "), dummy))
         {
             // not used anymore
         }
-        ReadParamIfNotSet(ReadTextLine(&f, &encConv),
+        ReadParamIfNotSet(ReadTextLine(&f),
                   _T("#. Language: "), m_header.Language);
-        dummy = ReadTextLine(&f, &encConv);
+        dummy = ReadTextLine(&f);
         if (ReadParamIfNotSet(dummy, _T("#. Country: "), m_header.Country))
-            dummy = ReadTextLine(&f, NULL);
+            dummy = ReadTextLine(&f);
         if (ReadParamIfNotSet(dummy, _T("#. Basepath: "), m_header.BasePath))
-            dummy = ReadTextLine(&f, NULL);
+            dummy = ReadTextLine(&f);
         ReadParamIfNotSet(dummy, _T("#. SourceCodeCharSet: "), m_header.SourceCodeCharset);
 
-        if (ReadParam(ReadTextLine(&f, NULL), _T("#. Paths: "), dummy))
+        if (ReadParam(ReadTextLine(&f), _T("#. Paths: "), dummy))
         {
-            bool setPaths = m_header.SearchPaths.IsEmpty();
+            bool setPaths = m_header.SearchPaths.empty();
             long sz;
             dummy.ToLong(&sz);
             for (; sz > 0; sz--)
             {
-                if (ReadParam(ReadTextLine(&f, NULL), _T("#.     "), dummy))
+                if (ReadParam(ReadTextLine(&f), _T("#.     "), dummy))
                 {
                     if (setPaths)
                         m_header.SearchPaths.Add(dummy);
@@ -1041,14 +1026,14 @@ bool Catalog::Load(const wxString& po_file)
             }
         }
 
-        if (ReadParam(ReadTextLine(&f, NULL), _T("#. Keywords: "), dummy))
+        if (ReadParam(ReadTextLine(&f), _T("#. Keywords: "), dummy))
         {
-            bool setKeyw = m_header.Keywords.IsEmpty();
+            bool setKeyw = m_header.Keywords.empty();
             long sz;
             dummy.ToLong(&sz);
             for (; sz > 0; sz--)
             {
-                if (ReadParam(ReadTextLine(&f, NULL), _T("#.     "), dummy))
+                if (ReadParam(ReadTextLine(&f), _T("#.     "), dummy))
                 {
                     if (setKeyw)
                         m_header.Keywords.Add(dummy);
@@ -1076,7 +1061,7 @@ void Catalog::AddDeletedItem(CatalogDeletedData *data)
 
 bool Catalog::HasDeletedItems()
 {
-    return !m_deletedItemsArray.IsEmpty();
+    return !m_deletedItemsArray.empty();
 }
 
 void Catalog::RemoveDeletedItems()
@@ -1121,32 +1106,10 @@ int Catalog::SetBookmark(int id, Bookmark bookmark)
 
 static bool CanEncodeStringToCharset(const wxString& s, wxMBConv& conv)
 {
-    if (s.IsEmpty())
+    if (s.empty())
         return true;
-#if !wxUSE_UNICODE
-    wxString trans(s.wc_str(wxConvUTF8), conv);
-    if (!trans)
-        return false;
-    #ifdef __WINDOWS__
-    // NB: there's an inconsistency in wxWindows (fixed in wx-2.5.2):
-    //     wxMBConv conversion rountines return NULL (i.e. empty wxString) in
-    //     case of failure on Unix (iconv) but return lossy/inexact conversion
-    //     if exact conversion cannot be done on Windows. So we have to do
-    //     roundtrip conversion and compare the result with original to see if
-    //     the conversion was successful or not:
-    wxString roundtrip(trans.wc_str(conv), wxConvUTF8);
-    if (roundtrip != s)
-        return false;
-    #endif
-#else
     if (!s.mb_str(conv))
         return false;
-    #ifdef __WINDOWS__
-    wxString roundtrip(s.mb_str(conv), conv);
-    if (roundtrip != s)
-        return false;
-    #endif
-#endif
     return true;
 }
 
@@ -1236,16 +1199,6 @@ static wxString FormatStringForFile(const wxString& text)
         return s;
 }
 
-static inline wxString convertUtf8ToCharset(const wxString& s, wxMBConv *conv)
-{
-#if !wxUSE_UNICODE
-    if (conv)
-        return wxString(s.wc_str(wxConvUTF8), *conv);
-    else
-#endif
-    return s;
-}
-
 bool Catalog::Save(const wxString& po_file, bool save_mo)
 {
     CatalogData *data;
@@ -1272,7 +1225,8 @@ bool Catalog::Save(const wxString& po_file, bool save_mo)
 
     /* Detect CRLF format: */
 
-    if (crlfPreserve && wxFileExists(po_file) && f.Open(po_file))
+    if ( crlfPreserve && wxFileExists(po_file) &&
+         f.Open(po_file, wxConvISO8859_1) )
     {
         {
         wxLogNull null;
@@ -1301,28 +1255,19 @@ bool Catalog::Save(const wxString& po_file, bool save_mo)
     }
     m_header.Charset = charset;
 
-    if (!wxFileExists(po_file) || !f.Open(po_file))
+    if (!wxFileExists(po_file) || !f.Open(po_file, wxConvISO8859_1))
         if (!f.Create(po_file))
             return false;
     for (j = f.GetLineCount() - 1; j >= 0; j--)
         f.RemoveLine(j);
 
 
-    wxCSConv *encConv;
-#if wxUSE_UNICODE
-    encConv = new wxCSConv(charset);
-#else
-    if (wxStricmp(charset, _T("utf-8")) != 0)
-        encConv = new wxCSConv(charset);
-    else
-        encConv = NULL;
-#endif
+    wxCSConv encConv(charset);
 
-    SaveMultiLines(f, convertUtf8ToCharset(m_header.Comment, encConv));
+    SaveMultiLines(f, m_header.Comment);
     f.AddLine(_T("msgid \"\""));
     f.AddLine(_T("msgstr \"\""));
-    wxString pohdr = wxString(_T("\"")) +
-               convertUtf8ToCharset(m_header.ToString(_T("\"\n\"")), encConv);
+    wxString pohdr = wxString(_T("\"")) + m_header.ToString(_T("\"\n\""));
     pohdr.RemoveLast();
     SaveMultiLines(f, pohdr);
     f.AddLine(wxEmptyString);
@@ -1330,7 +1275,7 @@ bool Catalog::Save(const wxString& po_file, bool save_mo)
     for (i = 0; i < m_dataArray.GetCount(); i++)
     {
         data = &(m_dataArray[i]);
-        SaveMultiLines(f, convertUtf8ToCharset(data->GetComment(), encConv));
+        SaveMultiLines(f, data->GetComment());
         for (unsigned i = 0; i < data->GetAutoComments().GetCount(); i++)
         {
             if (data->GetAutoComments()[i].empty())
@@ -1341,33 +1286,26 @@ bool Catalog::Save(const wxString& po_file, bool save_mo)
         for (unsigned i = 0; i < data->GetReferences().GetCount(); i++)
             f.AddLine(_T("#: ") + data->GetReferences()[i]);
         dummy = data->GetFlags();
-        if (!dummy.IsEmpty())
+        if (!dummy.empty())
             f.AddLine(dummy);
-        dummy = convertUtf8ToCharset(FormatStringForFile(data->GetString()),
-                                     encConv);
+        dummy = FormatStringForFile(data->GetString());
         data->SetLineNumber(f.GetLineCount()+1);
         SaveMultiLines(f, _T("msgid \"") + dummy + _T("\""));
         if (data->HasPlural())
         {
-            dummy = convertUtf8ToCharset(
-                        FormatStringForFile(data->GetPluralString()),
-                        encConv);
+            dummy = FormatStringForFile(data->GetPluralString());
             SaveMultiLines(f, _T("msgid_plural \"") + dummy + _T("\""));
 
             for (size_t i = 0; i < data->GetNumberOfTranslations(); i++)
             {
-                dummy = convertUtf8ToCharset(
-                            FormatStringForFile(data->GetTranslation(i)),
-                            encConv);
+                dummy = FormatStringForFile(data->GetTranslation(i));
                 wxString hdr = wxString::Format(_T("msgstr[%u] \""), i);
                 SaveMultiLines(f, hdr + dummy + _T("\""));
             }
         }
         else
         {
-            dummy = convertUtf8ToCharset(
-                        FormatStringForFile(data->GetTranslation()),
-                        encConv);
+            dummy = FormatStringForFile(data->GetTranslation());
             SaveMultiLines(f, _T("msgstr \"") + dummy + _T("\""));
         }
         f.AddLine(wxEmptyString);
@@ -1377,28 +1315,24 @@ bool Catalog::Save(const wxString& po_file, bool save_mo)
     for (i = 0; i < m_deletedItemsArray.GetCount(); i++)
     {
         deletedItem = &(m_deletedItemsArray[i]);
-        SaveMultiLines(f, convertUtf8ToCharset(deletedItem->GetComment(), encConv));
+        SaveMultiLines(f, deletedItem->GetComment());
         for (unsigned i = 0; i < deletedItem->GetAutoComments().GetCount(); i++)
             f.AddLine(_T("#. ") + deletedItem->GetAutoComments()[i]);
         for (unsigned i = 0; i < deletedItem->GetReferences().GetCount(); i++)
             f.AddLine(_T("#: ") + deletedItem->GetReferences()[i]);
         dummy = deletedItem->GetFlags();
-        if (!dummy.IsEmpty())
+        if (!dummy.empty())
             f.AddLine(dummy);
         deletedItem->SetLineNumber(f.GetLineCount()+1);
 
         for (size_t j = 0; j < deletedItem->GetDeletedLines().GetCount(); j++)
-            f.AddLine(convertUtf8ToCharset(deletedItem->GetDeletedLines()[j], encConv));
+            f.AddLine(deletedItem->GetDeletedLines()[j]);
 
         f.AddLine(wxEmptyString);
     }
 
 
-#if wxUSE_UNICODE
-    f.Write(crlf, *encConv);
-#else
-    f.Write(crlf);
-#endif
+    f.Write(crlf, encConv);
     f.Close();
 
     /* poEdit < 1.3.0 used to save additional info in .po.poedit file. It's
@@ -1408,8 +1342,6 @@ bool Catalog::Save(const wxString& po_file, bool save_mo)
         wxRemoveFile(po_file + _T(".poedit"));
     }
 
-    delete encConv;
-
     /* If the user wants it, compile .mo file right now: */
 
     if (save_mo && wxConfig::Get()->Read(_T("compile_mo"), true))
@@ -1448,7 +1380,7 @@ bool Catalog::Update(bool summary)
     SourceDigger dig(&pinfo);
 
     wxArrayString keywords;
-    if (m_header.Keywords.IsEmpty())
+    if (m_header.Keywords.empty())
     {
         // NB: keep in sync with Catalog::CreateNewHeader!
         keywords.Add(_T("_"));
@@ -1635,7 +1567,7 @@ void Catalog::Append(Catalog& cat)
         {
             for (unsigned j = 0; j < dt->GetReferences().GetCount(); j++)
                 mydt->AddReference(dt->GetReferences()[j]);
-            if (!dt->GetTranslation().IsEmpty())
+            if (!dt->GetTranslation().empty())
                 mydt->SetTranslation(dt->GetTranslation());
             if (dt->IsFuzzy()) mydt->SetFuzzy(true);
         }
@@ -1667,7 +1599,7 @@ void CatalogData::SetFlags(const wxString& flags)
     m_isFuzzy = false;
     m_moreFlags.Empty();
 
-    if (flags.IsEmpty()) return;
+    if (flags.empty()) return;
     wxStringTokenizer tkn(flags.Mid(1), _T(" ,"), wxTOKEN_STRTOK);
     wxString s;
     while (tkn.HasMoreTokens())
@@ -1684,7 +1616,7 @@ wxString CatalogData::GetFlags() const
     wxString f;
     if (m_isFuzzy) f << _T(", fuzzy");
     f << m_moreFlags;
-    if (!f.IsEmpty())
+    if (!f.empty())
         return _T("#") + f;
     else
         return wxEmptyString;
@@ -1720,7 +1652,7 @@ void CatalogData::SetTranslation(const wxString &t, unsigned idx)
     m_validity = Val_Unknown;
     m_isTranslated = false;
     for (size_t i = 0; i < m_translations.GetCount(); i++)
-        if (!m_translations[i].IsEmpty())
+        if (!m_translations[i].empty())
             m_isTranslated = true;
 }
 
@@ -1731,7 +1663,7 @@ void CatalogData::SetTranslations(const wxArrayString &t)
     m_validity = Val_Unknown;
     m_isTranslated = false;
     for (size_t i = 0; i < m_translations.GetCount(); i++)
-        if (!m_translations[i].IsEmpty())
+        if (!m_translations[i].empty())
             m_isTranslated = true;
 }
 
@@ -1741,10 +1673,10 @@ wxString Catalog::GetLocaleCode() const
     wxString lang;
 
     // was the language explicitly specified?
-    if (!m_header.Language.IsEmpty())
+    if (!m_header.Language.empty())
     {
         lang = LookupLanguageCode(m_header.Language.c_str());
-        if (!m_header.Country.IsEmpty())
+        if (!m_header.Country.empty())
         {
             lang += _T('_');
             lang += LookupCountryCode(m_header.Country.c_str());
