@@ -1,7 +1,7 @@
 /*
- *  This file is part of poEdit (http://www.poedit.org)
+ *  This file is part of poEdit (http://www.poedit.net)
  *
- *  Copyright (C) 1999-2005 Vaclav Slavik
+ *  Copyright (C) 1999-2007 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE. 
  *
- *  $Id: catalog.h 1008 2006-05-28 19:24:57Z vaclavslavik $
+ *  $Id: catalog.h 1116 2007-06-16 20:56:34Z vaclavslavik $
  *
  *  Translations catalog
  *
@@ -289,8 +289,7 @@ class Catalog
 class CatalogParser
 {
     public:
-        CatalogParser(wxTextFile *f, wxMBConv *conv)
-            : m_textFile(f), m_conv(conv) {}
+        CatalogParser(wxTextFile *f) : m_textFile(f) {}
         virtual ~CatalogParser() {}
 
         /** Parses the entire file, calls OnEntry each time
@@ -331,7 +330,6 @@ class CatalogParser
 
         /// Textfile being parsed.
         wxTextFile *m_textFile;
-        wxMBConv   *m_conv;
 };
 
 /** This class holds information about one particular string.
@@ -405,7 +403,7 @@ class CatalogData : public wxObject
         const wxArrayString& GetAutoComments() const { return m_autocomments; }
 
         /// Convenience function: does this entry has a comment?
-        const bool HasComment() const { return !m_comment.IsEmpty(); }
+        const bool HasComment() const { return !m_comment.empty(); }
 
         /// Adds new reference to the entry (used by SourceDigger).
         void AddReference(const wxString& ref)
@@ -574,7 +572,7 @@ class CatalogDeletedData : public wxObject
         const wxArrayString& GetAutoComments() const { return m_autocomments; }
 
         /// Convenience function: does this entry has a comment?
-        const bool HasComment() const { return !m_comment.IsEmpty(); }
+        const bool HasComment() const { return !m_comment.empty(); }
 
         /// Adds new reference to the entry (used by SourceDigger).
         void AddReference(const wxString& ref)
