@@ -1,5 +1,5 @@
 /*
- *  This file is part of poEdit (http://www.poedit.org)
+ *  This file is part of poEdit (http://www.poedit.net)
  *
  *  Copyright (C) 2003-2006 Vaclav Slavik
  *
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: chooselang.cpp 1045 2006-10-08 11:40:52Z vaclavslavik $
+ *  $Id: chooselang.cpp 1066 2007-03-21 17:27:08Z vaclavslavik $
  *
  *  Language chooser
  *
@@ -147,6 +147,7 @@ wxLanguage ChooseLanguage()
         { _T("Thai"), wxLANGUAGE_THAI },
         { _T("Turkish"), wxLANGUAGE_TURKISH },
         { _T("Ukrainian"), wxLANGUAGE_UKRAINIAN },
+        { _T("Urdu"), wxLANGUAGE_URDU },
 
         { NULL, wxLANGUAGE_UNKNOWN }
     };
