@@ -1,7 +1,7 @@
 /*
- *  This file is part of poEdit (http://www.poedit.org)
+ *  This file is part of poEdit (http://www.poedit.net)
  *
- *  Copyright (C) 1999-2006 Vaclav Slavik
+ *  Copyright (C) 1999-2007 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: edapp.cpp 1052 2006-10-29 18:31:48Z vaclavslavik $
+ *  $Id: edapp.cpp 1116 2007-06-16 20:56:34Z vaclavslavik $
  *
  *  Application class
  *
@@ -39,6 +39,10 @@
 #include <wx/xrc/xh_all.h>
 #include <wx/stdpaths.h>
 
+#if !wxUSE_UNICODE
+    #error "Unicode build of wxWidgets is required by poEdit"
+#endif
+
 #include "edapp.h"
 #include "edframe.h"
 #include "manager.h"
@@ -74,12 +78,14 @@ wxString poEditApp::GetAppPath() const
 
 wxString poEditApp::GetAppVersion() const
 {
-    wxString version(_T("1.3.6"));
+    wxString version(_T("1.3.7"));
     return version;
 }
 
 
+#ifndef __WXMAC__
 static wxArrayString gs_filesToOpen;
+#endif
 
 extern void InitXmlResource();
 
@@ -106,13 +112,22 @@ bool poEditApp::OnInit()
     SetVendorName(_T("Vaclav Slavik"));
     SetAppName(_T("poedit"));
 
-    #if defined(__WXMAC__)
-    #define CFG_FILE (wxStandardPaths::Get().GetUserConfigDir() + _T("/poedit.cfg"))
-    #elif defined(__UNIX__)
+#if defined(__WXMAC__)
+    #define CFG_FILE (wxStandardPaths::Get().GetUserConfigDir() + _T("/net.poedit.Poedit.cfg"))
+#elif defined(__UNIX__)
     #define CFG_FILE (home + _T(".poedit/config"))
-    #else
+#else
     #define CFG_FILE wxEmptyString
-    #endif
+#endif
+
+#ifdef __WXMAC__
+    // upgrade from the old location of config file:
+    wxString oldcfgfile = wxStandardPaths::Get().GetUserConfigDir() + _T("/poedit.cfg");
+    if (wxFileExists(oldcfgfile) && !wxFileExists(CFG_FILE))
+    {
+        wxRenameFile(oldcfgfile, CFG_FILE);
+    }
+#endif
 
     wxConfigBase::Set(
         new wxConfig(wxEmptyString, wxEmptyString, CFG_FILE, wxEmptyString, 
@@ -139,7 +154,7 @@ bool poEditApp::OnInit()
     SetDefaultCfg(wxConfig::Get());
 
 #ifdef HAS_INSERT_PROVIDER
-    wxArtProvider::InsertProvider(new PoeditArtProvider);
+    wxArtProvider::Insert(new PoeditArtProvider);
 #else
     wxArtProvider::PushProvider(new PoeditArtProvider);
 #endif
@@ -148,30 +163,45 @@ bool poEditApp::OnInit()
     {
         wxMessageBox(_("This is first time you run poEdit.\nPlease fill in your name and e-mail address.\n(This information is used only in catalogs headers)"), _("Setup"),
                        wxOK | wxICON_INFORMATION);
-                       
+
         PreferencesDialog dlg;
         dlg.TransferTo(wxConfig::Get());
         if (dlg.ShowModal() == wxID_OK)
             dlg.TransferFrom(wxConfig::Get());
     }
-      
+
+    // opening files or creating empty window is handled differently on Macs,
+    // using MacOpenFile() and MacNewFile(), so don't do it here:
+#ifndef __WXMAC__
     if (gs_filesToOpen.GetCount() == 0)
-     
     {
-        if (wxConfig::Get()->Read(_T("manager_startup"), (long)false))
-            ManagerFrame::Create()->Show(true);
-        else
-            poEditFrame::Create(wxEmptyString);
+        OpenNewFile();
     }
     else
     {
         for (size_t i = 0; i < gs_filesToOpen.GetCount(); i++)
-            poEditFrame::Create(gs_filesToOpen[i]);
+            OpenFile(gs_filesToOpen[i]);
+        gs_filesToOpen.clear();
     }
+#endif // !__WXMAC__
 
     return true;
 }
-    
+
+
+void poEditApp::OpenNewFile()
+{
+    if (wxConfig::Get()->Read(_T("manager_startup"), (long)false))
+        ManagerFrame::Create()->Show(true);
+    else
+        poEditFrame::Create(wxEmptyString);
+}
+
+void poEditApp::OpenFile(const wxString& name)
+{
+    poEditFrame::Create(name);
+}
+
 void poEditApp::SetDefaultParsers(wxConfigBase *cfg)
 {
     ParsersDB pdb;
@@ -261,7 +291,7 @@ void poEditApp::SetDefaultCfg(wxConfigBase *cfg)
 
     if (cfg->Read(_T("version"), wxEmptyString) == GetAppVersion()) return;
 
-    if (cfg->Read(_T("TM/database_path"), wxEmptyString).IsEmpty())
+    if (cfg->Read(_T("TM/database_path"), wxEmptyString).empty())
     {
         wxString dbpath;
 #if defined(__WXMAC__)
@@ -280,7 +310,7 @@ void poEditApp::SetDefaultCfg(wxConfigBase *cfg)
         cfg->Write(_T("TM/database_path"), dbpath);
     }
 
-    if (cfg->Read(_T("TM/search_paths"), wxEmptyString).IsEmpty())
+    if (cfg->Read(_T("TM/search_paths"), wxEmptyString).empty())
     {
         wxString paths;
 #if defined(__UNIX__)
@@ -304,9 +334,12 @@ void poEditApp::OnInitCmdLine(wxCmdLineParser& parser)
 bool poEditApp::OnCmdLineParsed(wxCmdLineParser& parser)
 {
     if (!wxApp::OnCmdLineParsed(parser))
-        return FALSE;
+        return false;
 
+#ifndef __WXMAC__
     for (size_t i = 0; i < parser.GetParamCount(); i++)
         gs_filesToOpen.Add(parser.GetParam(i));
-    return TRUE;
+#endif
+
+    return true;
 }
