@@ -1,5 +1,5 @@
 /*
- *  This file is part of poEdit (http://www.poedit.org)
+ *  This file is part of poEdit (http://www.poedit.net)
  *
  *  Copyright (C) 1999-2006 Vaclav Slavik
  *
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE. 
  *
- *  $Id: edapp.h 1021 2006-08-31 17:49:13Z vaclavslavik $
+ *  $Id: edapp.h 1102 2007-06-12 21:24:56Z vaclavslavik $
  *
  *  Editor application object
  *
@@ -59,10 +59,20 @@ class poEditApp : public wxApp
 
         /// Returns poEdit version string.
         wxString GetAppVersion() const;
-        
+
         /// Returns our locale object
         wxLocale& GetLocale() { return m_locale; }
 
+        // opens a file in new frame
+        void OpenFile(const wxString& name);
+        // opens empty frame or catalogs manager
+        void OpenNewFile();
+
+#ifdef __WXMAC__
+        virtual void MacOpenFile(const wxString& name) { OpenFile(name); }
+        virtual void MacNewFile() { OpenNewFile(); }
+#endif
+
     protected:
         /** Sets default values to configuration items that don't
             have anything set. (This may happen after fresh installation or
