@@ -1,7 +1,7 @@
 /*
- *  This file is part of poEdit (http://www.poedit.org)
+ *  This file is part of poEdit (http://www.poedit.net)
  *
- *  Copyright (C) 1999-2006 Vaclav Slavik
+ *  Copyright (C) 1999-2007 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE. 
  *
- *  $Id: edframe.cpp 1051 2006-10-29 18:23:21Z vaclavslavik $
+ *  $Id: edframe.cpp 1160 2007-06-30 16:58:45Z vaclavslavik $
  *
  *  Editor frame
  *
@@ -45,6 +45,13 @@
 #include <wx/fontutil.h>
 #include <wx/textfile.h>
 
+#if !wxCHECK_VERSION(2,8,0)
+    #define wxFD_OPEN              wxOPEN
+    #define wxFD_SAVE              wxSAVE
+    #define wxFD_OVERWRITE_PROMPT  wxOVERWRITE_PROMPT
+    #define wxFD_FILE_MUST_EXIST   wxFILE_MUST_EXIST
+#endif
+
 #if USE_SPELLCHECKING
     #include <gtk/gtk.h>
     extern "C" {
@@ -104,10 +111,11 @@ const wxWindowID ID_TEXTCOMMENT = wxNewId();
 
 /*static*/ poEditFrame *poEditFrame::Find(const wxString& filename)
 {
-    for (poEditFramesList::Node *n = ms_instances.GetFirst(); n; n = n->GetNext())
+    for (poEditFramesList::const_iterator n = ms_instances.begin();
+         n != ms_instances.end(); ++n)
     {
-        if (n->GetData()->m_fileName == filename)
-            return n->GetData();
+        if ((*n)->m_fileName == filename)
+            return *n;
     }
     return NULL;
 }
@@ -148,11 +156,20 @@ class TextctrlHandler : public wxEvtHandler
         {
             int keyCode = event.GetKeyCode();
 
+            if (!event.ControlDown())
+            {
+                event.Skip();
+                return;
+            }
+
             switch (keyCode)
             {
                 case WXK_UP:
-                    if ((*m_sel > 0) && event.ControlDown())
+                    if ((*m_sel > 0))
                     {
+#ifdef __WXMAC__
+                        m_list->SetItemState(*m_sel, 0, wxLIST_STATE_SELECTED);
+#endif
                         m_list->EnsureVisible(*m_sel - 1);
                         m_list->SetItemState(*m_sel - 1, wxLIST_STATE_SELECTED, wxLIST_STATE_SELECTED);
                     }
@@ -160,37 +177,40 @@ class TextctrlHandler : public wxEvtHandler
                         event.Skip();
                     break;
                 case WXK_DOWN:
-                    if ((*m_sel < m_list->GetItemCount() - 1) && event.ControlDown())
+                    if ((*m_sel < m_list->GetItemCount() - 1))
                     {
+#ifdef __WXMAC__
+                        m_list->SetItemState(*m_sel, 0, wxLIST_STATE_SELECTED);
+#endif
                         m_list->EnsureVisible(*m_sel + 1);
                         m_list->SetItemState(*m_sel + 1, wxLIST_STATE_SELECTED, wxLIST_STATE_SELECTED);
                     }
                     else
                         event.Skip();
                     break;
-                case WXK_PRIOR:
-                    if (event.ControlDown())
-                    {
-                        int newy = *m_sel - 10;
-                        if (newy < 0) newy = 0;
-                        m_list->EnsureVisible(newy);
-                        m_list->SetItemState(newy, wxLIST_STATE_SELECTED, wxLIST_STATE_SELECTED);
-                    }
-                    else
-                        event.Skip();
+                case WXK_PAGEUP:
+                {
+#ifdef __WXMAC__
+                    m_list->SetItemState(*m_sel, 0, wxLIST_STATE_SELECTED);
+#endif
+                    int newy = *m_sel - 10;
+                    if (newy < 0) newy = 0;
+                    m_list->EnsureVisible(newy);
+                    m_list->SetItemState(newy, wxLIST_STATE_SELECTED, wxLIST_STATE_SELECTED);
                     break;
-                case WXK_NEXT:
-                    if (event.ControlDown())
-                    {
-                        int newy = *m_sel + 10;
-                        if (newy >= m_list->GetItemCount())
-                            newy = m_list->GetItemCount() - 1;
-                        m_list->EnsureVisible(newy);
-                        m_list->SetItemState(newy, wxLIST_STATE_SELECTED, wxLIST_STATE_SELECTED);
-                    }
-                    else
-                        event.Skip();
+                }
+                case WXK_PAGEDOWN:
+                {
+#ifdef __WXMAC__
+                    m_list->SetItemState(*m_sel, 0, wxLIST_STATE_SELECTED);
+#endif
+                    int newy = *m_sel + 10;
+                    if (newy >= m_list->GetItemCount())
+                        newy = m_list->GetItemCount() - 1;
+                    m_list->EnsureVisible(newy);
+                    m_list->SetItemState(newy, wxLIST_STATE_SELECTED, wxLIST_STATE_SELECTED);
                     break;
+                }
                 default:
                     event.Skip();
             }
@@ -243,31 +263,6 @@ BEGIN_EVENT_TABLE(ListHandler, wxEvtHandler)
    EVT_KEY_DOWN            (          ListHandler::OnKeyDown)
 END_EVENT_TABLE()
 
-class StatusbarHandler : public wxEvtHandler
-{
-    public:
-        StatusbarHandler(wxStatusBar *bar, wxGauge *gauge) :
-                 m_bar(bar), m_gauge(gauge) {}
-
-    private:
-        void OnSize(wxSizeEvent& event)
-        {
-            wxRect rect;
-            m_bar->GetFieldRect(1, rect);
-            m_gauge->SetSize(rect.x+2, rect.y+2, rect.width-4, rect.height-4);
-            event.Skip();
-        }
-
-        DECLARE_EVENT_TABLE()
-
-        wxStatusBar *m_bar;
-        wxGauge     *m_gauge;
-};
-
-BEGIN_EVENT_TABLE(StatusbarHandler, wxEvtHandler)
-   EVT_SIZE(StatusbarHandler::OnSize)
-END_EVENT_TABLE()
-
 
 class UnfocusableTextCtrl : public wxTextCtrl
 {
@@ -281,7 +276,7 @@ class UnfocusableTextCtrl : public wxTextCtrl
                             const wxValidator& validator = wxDefaultValidator,
                             const wxString &name = wxTextCtrlNameStr)
            : wxTextCtrl(parent, id, value, pos, size, style, validator, name) {}
-        virtual bool AcceptsFocus() const { return FALSE; }
+        virtual bool AcceptsFocus() const { return false; }
 };
 
 
@@ -292,9 +287,9 @@ BEGIN_EVENT_TABLE(poEditFrame, wxFrame)
    EVT_MENU           (wxID_ABOUT,                poEditFrame::OnAbout)
    EVT_MENU           (XRCID("menu_new"),         poEditFrame::OnNew)
    EVT_MENU           (XRCID("menu_new_from_pot"),poEditFrame::OnNew)
-   EVT_MENU           (XRCID("menu_open"),        poEditFrame::OnOpen)
-   EVT_MENU           (XRCID("menu_save"),        poEditFrame::OnSave)
-   EVT_MENU           (XRCID("menu_saveas"),      poEditFrame::OnSaveAs)
+   EVT_MENU           (wxID_OPEN,                 poEditFrame::OnOpen)
+   EVT_MENU           (wxID_SAVE,                 poEditFrame::OnSave)
+   EVT_MENU           (wxID_SAVEAS,               poEditFrame::OnSaveAs)
    EVT_MENU           (XRCID("menu_export"),      poEditFrame::OnExport)
    EVT_MENU_RANGE     (wxID_FILE1, wxID_FILE9,    poEditFrame::OnOpenHist)
    EVT_MENU           (XRCID("menu_catsettings"), poEditFrame::OnSettings)
@@ -310,7 +305,9 @@ BEGIN_EVENT_TABLE(poEditFrame, wxFrame)
    EVT_MENU           (XRCID("menu_shaded"),      poEditFrame::OnShadedListFlag)
    EVT_MENU           (XRCID("menu_insert_orig"), poEditFrame::OnInsertOriginal)
    EVT_MENU           (XRCID("menu_references"),  poEditFrame::OnReferencesMenu)
+#ifndef __WXMAC__
    EVT_MENU           (XRCID("menu_fullscreen"),  poEditFrame::OnFullscreen)
+#endif
    EVT_MENU           (XRCID("menu_find"),        poEditFrame::OnFind)
    EVT_MENU           (XRCID("menu_comment"),     poEditFrame::OnEditComment)
    EVT_MENU           (XRCID("menu_manager"),     poEditFrame::OnManager)
@@ -337,10 +334,7 @@ END_EVENT_TABLE()
 // Frame class:
 
 poEditFrame::poEditFrame() :
-    wxFrame(NULL, -1, _("poEdit"), wxDefaultPosition,
-                             wxSize(
-                                 wxConfig::Get()->Read(_T("frame_w"), 600),
-                                 wxConfig::Get()->Read(_T("frame_h"), 400)),
+    wxFrame(NULL, -1, _("poEdit"), wxDefaultPosition, wxDefaultSize,
                              wxDEFAULT_FRAME_STYLE | wxNO_FULL_REPAINT_ON_RESIZE),
 #if USE_GETTEXT_VALIDATION
     m_itemBeingValidated(-1), m_gettextProcess(NULL),
@@ -350,6 +344,7 @@ poEditFrame::poEditFrame() :
     m_transMem(NULL),
     m_transMemLoaded(false),
 #endif
+    m_helpInitialized(false),
     m_list(NULL),
     m_modified(false),
     m_hasObsoleteItems(false),
@@ -358,30 +353,22 @@ poEditFrame::poEditFrame() :
 {
     // make sure that the [ID_POEDIT_FIRST,ID_POEDIT_LAST] range of IDs is not
     // used for anything else:
-    wxASSERT_MSG( wxGetCurrentId() < ID_POEDIT_FIRST,
-                  _("detected ID values conflict!") );
+    wxASSERT_MSG( wxGetCurrentId() < ID_POEDIT_FIRST ||
+                  wxGetCurrentId() > ID_POEDIT_LAST,
+                  _T("detected ID values conflict!") );
     wxRegisterId(ID_POEDIT_LAST);
 
-#ifdef __WXMSW__
-    const int SPLITTER_BORDER = wxSP_NOBORDER;
+#if defined(__WXMSW__)
+    const int SPLITTER_FLAGS = wxSP_NOBORDER;
+#elif defined(__WXMAC__)
+    // wxMac doesn't show XORed line:
+    const int SPLITTER_FLAGS = wxSP_LIVE_UPDATE;
 #else
-    const int SPLITTER_BORDER = wxSP_3DBORDER;
+    const int SPLITTER_FLAGS = wxSP_3DBORDER;
 #endif
 
     wxConfigBase *cfg = wxConfig::Get();
 
-    // VS: a dirty hack of sort -- if this is the only poEdit frame opened,
-    //     place it at remembered position, but don't do that if there already
-    //     are other frames, because they would overlap and nobody could
-    //     recognize that there are many of them
-    if (ms_instances.GetCount() == 0)
-        Move(cfg->Read(_T("frame_x"), -1), cfg->Read(_T("frame_y"), -1));
-#if !defined(__WXGTK12__) || defined(__WXGTK20__)
-    // GTK+ 1.2 doesn't support this
-    if (cfg->Read(_T("frame_maximized"), long(0)))
-        Maximize();
-#endif
-
     m_displayQuotes = (bool)cfg->Read(_T("display_quotes"), (long)false);
     m_displayLines = (bool)cfg->Read(_T("display_lines"), (long)false);
     m_displayCommentWin =
@@ -433,9 +420,30 @@ poEditFrame::poEditFrame() :
     GetMenuBar()->Check(XRCID("menu_auto_comments_win"), m_displayAutoCommentsWin);
     GetMenuBar()->Check(XRCID("menu_shaded"), gs_shadedList);
 
+    CreateStatusBar(1, wxST_SIZEGRIP);
+
+    // NB: setting the position & size has to be the last thing done, otherwise
+    //     it's not done correctly on wxMac:
+    int posx = cfg->Read(_T("frame_x"), -1);
+    int posy = cfg->Read(_T("frame_y"), -1);
+    int width = cfg->Read(_T("frame_w"), 600);
+    int height = cfg->Read(_T("frame_h"), 400);
+
+    // NB: if this is the only poEdit frame opened, place it at remembered
+    //     position, but don't do that if there already are other frames,
+    //     because they would overlap and nobody could recognize that there are
+    //     many of them
+    if (ms_instances.GetCount() == 0)
+        SetSize(posx, posy, width, height);
+    else
+        SetSize(-1, -1, width, height);
+    if (cfg->Read(_T("frame_maximized"), long(0)))
+        Maximize();
+
+
     m_splitter = new wxSplitterWindow(this, -1,
                                       wxDefaultPosition, wxDefaultSize,
-                                      SPLITTER_BORDER);
+                                      SPLITTER_FLAGS);
 
     m_list = new poEditListCtrl(m_splitter,
                                 ID_LIST,
@@ -445,7 +453,7 @@ poEditFrame::poEditFrame() :
 
     m_bottomSplitter = new wxSplitterWindow(m_splitter, -1,
                                             wxDefaultPosition, wxDefaultSize,
-                                            SPLITTER_BORDER);
+                                            SPLITTER_FLAGS);
     m_bottomLeftPanel = new wxPanel(m_bottomSplitter);
     m_bottomRightPanel = new wxPanel(m_bottomSplitter);
 
@@ -517,31 +525,21 @@ poEditFrame::poEditFrame() :
     m_textTrans->PushEventHandler(new TextctrlHandler(this));
     m_textComment->PushEventHandler(new TextctrlHandler(this));
 
-    m_list->SetFocus();
-
-    int widths[] = {-1, 200};
-    CreateStatusBar(2, wxST_SIZEGRIP);
-    wxStatusBar *bar = GetStatusBar();
-    m_statusGauge = new wxGauge(bar, -1, 100, wxDefaultPosition, wxDefaultSize, wxGA_SMOOTH);
-    bar->SetStatusWidths(2, widths);
-    bar->PushEventHandler(new StatusbarHandler(bar, m_statusGauge));
-#ifdef __WXMSW__
-    bar->SetSize(-1,-1,-1,-1);
-#endif
-
     ShowPluralFormUI(false);
 
     UpdateMenu();
     UpdateDisplayCommentWin();
 
-    m_helpBook = LoadHelpBook(_T("poedit"));
-    m_helpBookGettext = LoadHelpBook(_T("gettext/gettext"));
-
     ms_instances.Append(this);
 
 #ifdef __WXMSW__
     DragAcceptFiles(true);
 #endif
+
+    if (gs_focusToText)
+        m_textTrans->SetFocus();
+    else
+        m_list->SetFocus();
 }
 
 
@@ -555,13 +553,9 @@ poEditFrame::~poEditFrame()
 
     ms_instances.DeleteObject(this);
 
-    GetStatusBar()->PopEventHandler(true/*delete*/);
     m_textTrans->PopEventHandler(true/*delete*/);
     m_list->PopEventHandler(true/*delete*/);
 
-    wxSize sz = GetSize();
-    wxPoint pos = GetPosition();
-
     wxConfigBase *cfg = wxConfig::Get();
     cfg->SetPath(_T("/"));
 
@@ -569,6 +563,9 @@ poEditFrame::~poEditFrame()
     {
         if (!IsMaximized())
         {
+            wxPoint pos = GetPosition();
+            wxSize sz = GetSize();
+
             cfg->Write(_T("frame_w"), (long)sz.x);
             cfg->Write(_T("frame_h"), (long)sz.y);
             cfg->Write(_T("frame_x"), (long)pos.x);
@@ -608,6 +605,16 @@ poEditFrame::~poEditFrame()
     InitSpellchecker();
 }
 
+void poEditFrame::InitHelp()
+{
+    if ( !m_helpInitialized )
+    {
+        m_helpBook = LoadHelpBook(_T("poedit"));
+        m_helpBookGettext = LoadHelpBook(_T("gettext/gettext"));
+        m_helpInitialized = true;
+    }
+}
+
 wxString poEditFrame::LoadHelpBook(const wxString& name)
 {
     wxString lng = wxGetApp().GetLocale().GetCanonicalName().Left(2);
@@ -755,7 +762,7 @@ TranslationMemory *poEditFrame::GetTransMem()
                 lang = lngs[index];
         }
 
-        if (!lang.IsEmpty() && TranslationMemory::IsSupported(lang, dbPath))
+        if (!lang.empty() && TranslationMemory::IsSupported(lang, dbPath))
         {
             m_transMem = TranslationMemory::Create(lang, dbPath);
             if (m_transMem)
@@ -831,9 +838,9 @@ void poEditFrame::OnOpen(wxCommandEvent&)
 
     wxString name = wxFileSelector(_("Open catalog"),
                     path, wxEmptyString, wxEmptyString,
-                    _("GNU GetText catalogs (*.po)|*.po|All files (*.*)|*.*"),
-                    wxOPEN | wxFILE_MUST_EXIST, this);
-    if (!name.IsEmpty())
+                    _("GNU Gettext catalogs (*.po)|*.po|All files (*.*)|*.*"),
+                    wxFD_OPEN | wxFD_FILE_MUST_EXIST, this);
+    if (!name.empty())
     {
         wxConfig::Get()->Write(_T("last_file_path"), wxPathOnly(name));
         ReadCatalog(name);
@@ -919,7 +926,7 @@ void poEditFrame::OnFileDrop(wxDropFilesEvent& event)
 void poEditFrame::OnSave(wxCommandEvent& event)
 {
     UpdateFromTextCtrl();
-    if (m_fileName.IsEmpty())
+    if (m_fileName.empty())
         OnSaveAs(event);
     else
         WriteCatalog(m_fileName);
@@ -950,8 +957,8 @@ wxString poEditFrame::GetSaveAsFilename(Catalog *cat, const wxString& current)
     }
 
     name = wxFileSelector(_("Save as..."), path, name, wxEmptyString,
-                          _("GNU GetText catalogs (*.po)|*.po|All files (*.*)|*.*"),
-                          wxSAVE | wxOVERWRITE_PROMPT, this);
+                          _("GNU Gettext catalogs (*.po)|*.po|All files (*.*)|*.*"),
+                          wxFD_SAVE | wxFD_OVERWRITE_PROMPT, this);
     if (!name.empty())
     {
         wxConfig::Get()->Write(_T("last_file_path"), wxPathOnly(name));
@@ -993,8 +1000,8 @@ void poEditFrame::OnExport(wxCommandEvent&)
     name = wxFileSelector(_("Export as..."),
                           wxPathOnly(m_fileName), name, wxEmptyString,
                           _("HTML file (*.html)|*.html"),
-                          wxSAVE | wxOVERWRITE_PROMPT, this);
-    if (!name.IsEmpty())
+                          wxFD_SAVE | wxFD_OVERWRITE_PROMPT, this);
+    if (!name.empty())
     {
         wxConfig::Get()->Write(_T("last_file_path"), wxPathOnly(name));
         ExportCatalog(name);
@@ -1043,8 +1050,8 @@ void poEditFrame::OnNew(wxCommandEvent& event)
         wxString pot_file =
             wxFileSelector(_("Open catalog template"),
                  path, wxEmptyString, wxEmptyString,
-                 _("GNU GetText templates (*.pot)|*.pot|All files (*.*)|*.*"),
-                 wxOPEN | wxFILE_MUST_EXIST, this);
+                 _("GNU Gettext templates (*.pot)|*.pot|All files (*.*)|*.*"),
+                 wxFD_OPEN | wxFD_FILE_MUST_EXIST, this);
         bool ok = false;
         if (!pot_file.empty())
         {
@@ -1113,6 +1120,7 @@ void poEditFrame::OnSettings(wxCommandEvent&)
     {
         dlg.TransferFrom(m_catalog);
         m_modified = true;
+        UpdateFromTextCtrl();
         RecreatePluralTextCtrls();
         UpdateTitle();
         UpdateMenu();
@@ -1142,6 +1150,8 @@ void poEditFrame::OnPreferences(wxCommandEvent&)
 
 void poEditFrame::UpdateCatalog(const wxString& pot_file)
 {
+    wxBusyCursor bcur;
+
     CancelItemsValidation();
 
     UpdateFromTextCtrl();
@@ -1165,6 +1175,8 @@ void poEditFrame::UpdateCatalog(const wxString& pot_file)
 
 void poEditFrame::OnUpdate(wxCommandEvent& event)
 {
+    UpdateFromTextCtrl();
+
     wxString pot_file;
 
     if (event.GetId() == XRCID("menu_update_from_pot"))
@@ -1175,8 +1187,8 @@ void poEditFrame::OnUpdate(wxCommandEvent& event)
         pot_file =
             wxFileSelector(_("Open catalog template"),
                  path, wxEmptyString, wxEmptyString,
-                 _("GNU GetText templates (*.pot)|*.pot|All files (*.*)|*.*"),
-                 wxOPEN | wxFILE_MUST_EXIST, this);
+                 _("GNU Gettext templates (*.pot)|*.pot|All files (*.*)|*.*"),
+                 wxFD_OPEN | wxFD_FILE_MUST_EXIST, this);
         if (pot_file.empty())
             return;
         wxConfig::Get()->Write(_T("last_file_path"), wxPathOnly(pot_file));
@@ -1305,8 +1317,12 @@ void poEditFrame::ShowReference(int num)
 
     if (wxConfig::Get()->Read(_T("open_editor_immediately"), (long)false))
     {
-        FileViewer::OpenInEditor(basepath,
-                                 (*m_catalog)[m_list->GetIndexInCatalog(m_sel)].GetReferences()[num]);
+        wxString ref =
+            (*m_catalog)[m_list->GetIndexInCatalog(m_sel)].GetReferences()[num];
+        // translate windows-style paths to Unix ones, which
+        // are accepted on all platforms:
+        ref.Replace(_T("\\"), _T("/"));
+        FileViewer::OpenInEditor(basepath, ref);
     }
     else
     {
@@ -1357,6 +1373,7 @@ void poEditFrame::OnQuotesFlag(wxCommandEvent& event)
 
 void poEditFrame::OnLinesFlag(wxCommandEvent& event)
 {
+    UpdateFromTextCtrl();
     m_displayLines = GetMenuBar()->IsChecked(XRCID("menu_lines"));
     m_list->SetDisplayLines(m_displayLines);
     RefreshControls();
@@ -1366,17 +1383,20 @@ void poEditFrame::OnLinesFlag(wxCommandEvent& event)
 
 void poEditFrame::OnCommentWinFlag(wxCommandEvent& event)
 {
+    UpdateFromTextCtrl();
     UpdateDisplayCommentWin();
 }
 
 void poEditFrame::OnAutoCommentsWinFlag(wxCommandEvent& event)
 {
+    UpdateFromTextCtrl();
     UpdateDisplayCommentWin();
 }
 
 
 void poEditFrame::OnShadedListFlag(wxCommandEvent& event)
 {
+    UpdateFromTextCtrl();
     gs_shadedList = GetMenuBar()->IsChecked(XRCID("menu_shaded"));
     RefreshControls();
 }
@@ -1404,6 +1424,7 @@ void poEditFrame::OnInsertOriginal(wxCommandEvent& event)
 
 
 
+#ifndef __WXMAC__
 void poEditFrame::OnFullscreen(wxCommandEvent& event)
 {
     bool fs = IsFullScreen();
@@ -1426,6 +1447,7 @@ void poEditFrame::OnFullscreen(wxCommandEvent& event)
 
     ShowFullScreen(!fs, wxFULLSCREEN_NOBORDER | wxFULLSCREEN_NOCAPTION);
 }
+#endif // !__WXMAC__
 
 
 
@@ -1438,29 +1460,6 @@ void poEditFrame::OnFind(wxCommandEvent& event)
     f->Show(true);
 }
 
-
-inline wxString convertToLocalCharset(const wxString& str)
-{
-#if !wxUSE_UNICODE
-    wxString s2(str.wc_str(wxConvUTF8), wxConvLocal);
-    if (s2.empty() /*conversion failed*/)
-        return str;
-    else
-        return s2;
-#else
-    return str;
-#endif
-}
-
-inline wxString convertFromLocalCharset(const wxString& str)
-{
-#if !wxUSE_UNICODE
-    return wxString(str.wc_str(wxConvLocal), wxConvUTF8);
-#else
-    return str;
-#endif
-}
-
 static wxString TransformNewval(const wxString& val, bool displayQuotes)
 {
     wxString newval(val);
@@ -1513,11 +1512,7 @@ void poEditFrame::UpdateFromTextCtrl(int item)
         if (entry.HasPlural())
         {
             bool changed = false;
-#ifndef __VISUALC__
-    // unbelievably, VC++ doesn't define std::min/max()!
-    #define _cpp_min std::min
-#endif
-            size_t size = _cpp_min(m_textTransPlural.size(),
+            size_t size = std::min(m_textTransPlural.size(),
                                    m_edittedTextOrig.size());
 
             for (size_t i = 0; i < size; i++)
@@ -1541,13 +1536,6 @@ void poEditFrame::UpdateFromTextCtrl(int item)
 
     newval = TransformNewval(newval, m_displayQuotes);
 
-#if !wxUSE_UNICODE
-    // convert to UTF-8 using user's environment default charset (do it
-    // after calling m_list->SetItem because SetItem expects string in
-    // local charset, not UTF-8):
-    newval = convertFromLocalCharset(newval);
-#endif
-
     if (entry.HasPlural())
     {
         wxArrayString str;
@@ -1555,12 +1543,6 @@ void poEditFrame::UpdateFromTextCtrl(int item)
         {
             wxString val = TransformNewval(m_textTransPlural[i]->GetValue(),
                                            m_displayQuotes);
-#if !wxUSE_UNICODE
-            // convert to UTF-8 using user's environment default charset (do it
-            // after calling m_list->SetItem because SetItem expects string in
-            // local charset, not UTF-8):
-            val = convertFromLocalCharset(val);
-#endif
             str.Add(val);
         }
         entry.SetTranslations(str);
@@ -1579,7 +1561,7 @@ void poEditFrame::UpdateFromTextCtrl(int item)
 
     entry.SetModified(true);
     entry.SetAutomatic(false);
-    entry.SetTranslated(!newval.IsEmpty());
+    entry.SetTranslated(!newval.empty());
 
     m_list->RefreshItem(item);
 
@@ -1623,12 +1605,6 @@ void poEditFrame::UpdateToTextCtrl(int item)
     // remove "# " in front of every comment line
     t_c = CommentDialog::RemoveStartHash(t_c);
 
-#if !wxUSE_UNICODE
-    // Convert from UTF-8 to environment's default charset:
-    t_o = convertToLocalCharset(t_o);
-    t_c = convertToLocalCharset(t_c);
-#endif
-
     m_textOrig->SetValue(t_o);
 
     m_edittedTextOrig.clear();
@@ -1637,9 +1613,6 @@ void poEditFrame::UpdateToTextCtrl(int item)
     {
         wxString t_op = quote + entry.GetPluralString() + quote;
         t_op.Replace(_T("\\n"), _T("\\n\n"));
-#if !wxUSE_UNICODE
-        t_op = convertToLocalCharset(t_op);
-#endif
         m_textOrigPlural->SetValue(t_op);
 
         size_t formsCnt = m_textTransPlural.size();
@@ -1651,9 +1624,6 @@ void poEditFrame::UpdateToTextCtrl(int item)
         {
             t_t = quote + entry.GetTranslation(i) + quote;
             t_t.Replace(_T("\\n"), _T("\\n\n"));
-#if !wxUSE_UNICODE
-            t_t = convertToLocalCharset(t_t);
-#endif
             m_textTransPlural[i]->SetValue(t_t);
             if (m_displayQuotes)
                 m_textTransPlural[i]->SetInsertionPoint(1);
@@ -1664,9 +1634,6 @@ void poEditFrame::UpdateToTextCtrl(int item)
     {
         t_t = quote + entry.GetTranslation() + quote;
         t_t.Replace(_T("\\n"), _T("\\n\n"));
-#if !wxUSE_UNICODE
-        t_t = convertToLocalCharset(t_t);
-#endif
         m_textTrans->SetValue(t_t);
         if (m_displayQuotes)
             m_textTrans->SetInsertionPoint(1);
@@ -1690,6 +1657,8 @@ void poEditFrame::UpdateToTextCtrl(int item)
 
 void poEditFrame::ReadCatalog(const wxString& catalog)
 {
+    wxBusyCursor bcur;
+
     CancelItemsValidation();
 
     Catalog *cat = new Catalog(catalog);
@@ -1814,6 +1783,13 @@ void poEditFrame::UpdateStatusBar()
 
         txt.Printf(_("%i strings (%i fuzzy, %i bad tokens, %i not translated)"),
                    all, fuzzy, badtokens, untranslated);
+        // FIXME - add percentage to the status bar string
+#if 0
+        if (all > 0)
+            m_statusGauge->SetValue(100 * (all-fuzzy-badtokens-untranslated) / all);
+        else
+            m_statusGauge->SetValue(0);
+#endif
 
 #if USE_GETTEXT_VALIDATION
         if (!m_itemsToValidate.empty())
@@ -1827,10 +1803,6 @@ void poEditFrame::UpdateStatusBar()
 #endif
 
         GetStatusBar()->SetStatusText(txt);
-        if (all > 0)
-            m_statusGauge->SetValue(100 * (all-fuzzy-badtokens-untranslated) / all);
-        else
-            m_statusGauge->SetValue(0);
     }
 }
 
@@ -1860,10 +1832,10 @@ void poEditFrame::UpdateMenu()
 
     if (m_catalog == NULL)
     {
-        menubar->Enable(XRCID("menu_save"), false);
-        menubar->Enable(XRCID("menu_saveas"), false);
+        menubar->Enable(wxID_SAVE, false);
+        menubar->Enable(wxID_SAVEAS, false);
         menubar->Enable(XRCID("menu_export"), false);
-        toolbar->EnableTool(XRCID("menu_save"), false);
+        toolbar->EnableTool(wxID_SAVE, false);
         toolbar->EnableTool(XRCID("menu_update"), false);
         toolbar->EnableTool(XRCID("menu_fuzzy"), false);
         toolbar->EnableTool(XRCID("menu_comment"), false);
@@ -1878,10 +1850,10 @@ void poEditFrame::UpdateMenu()
     }
     else
     {
-        menubar->Enable(XRCID("menu_save"), true);
-        menubar->Enable(XRCID("menu_saveas"), true);
+        menubar->Enable(wxID_SAVE, true);
+        menubar->Enable(wxID_SAVEAS, true);
         menubar->Enable(XRCID("menu_export"), true);
-        toolbar->EnableTool(XRCID("menu_save"), true);
+        toolbar->EnableTool(wxID_SAVE, true);
         toolbar->EnableTool(XRCID("menu_fuzzy"), true);
         toolbar->EnableTool(XRCID("menu_comment"), true);
         menubar->EnableTop(1, true);
@@ -1897,6 +1869,13 @@ void poEditFrame::UpdateMenu()
         menubar->Enable(XRCID("menu_update"), doupdate);
         menubar->Enable(XRCID("menu_purge_deleted"),
                              m_catalog->HasDeletedItems());
+
+#ifdef __WXGTK__
+        // work around a wxGTK bug: enabling wxTextCtrl makes it editable too
+        // in wxGTK <= 2.8:
+        m_textOrig->SetEditable(false);
+        m_textOrigPlural->SetEditable(false);
+#endif
     }
 
     menubar->EnableTop(4, m_catalog != NULL);
@@ -1935,7 +1914,7 @@ bool poEditFrame::WriteCatalog(const wxString& catalog)
             CatalogData& dt = (*m_catalog)[i];
             if (dt.IsModified() && !dt.IsFuzzy() &&
                 dt.GetValidity() == CatalogData::Val_Valid &&
-                !dt.GetTranslation().IsEmpty())
+                !dt.GetTranslation().empty())
             {
                 tm->Store(dt.GetString(), dt.GetTranslation());
             }
@@ -1960,14 +1939,13 @@ void poEditFrame::OnEditComment(wxCommandEvent& event)
     int selItem = m_list->GetIndexInCatalog(m_sel);
     if (selItem < 0 || selItem >= (int)m_catalog->GetCount()) return;
 
-    wxString comment = convertToLocalCharset(
-                            (*m_catalog)[selItem].GetComment());
+    wxString comment = (*m_catalog)[selItem].GetComment();
     CommentDialog dlg(this, comment);
     if (dlg.ShowModal() == wxID_OK)
     {
         m_modified = true;
         UpdateTitle();
-        comment = convertFromLocalCharset(dlg.GetComment());
+        comment = dlg.GetComment();
         (*m_catalog)[selItem].SetComment(comment);
 
         m_list->RefreshItem(m_sel);
@@ -1981,7 +1959,7 @@ void poEditFrame::OnPurgeDeleted(wxCommandEvent& WXUNUSED(event))
 {
     wxMessageDialog dlg(this,
                         _("Do you really want to remove all translations that are no longer used from the catalog?\nIf you continue with purging, you will have to translate them again if they are added back in the future."),
-                        _("Purge delete translations"),
+                        _("Purge deleted translations"),
                         wxYES_NO | wxICON_QUESTION);
 
     if (dlg.ShowModal() == wxID_YES)
@@ -2011,6 +1989,8 @@ void poEditFrame::OnAutoTranslateAll(wxCommandEvent& event)
 
 bool poEditFrame::AutoTranslateCatalog()
 {
+    wxBusyCursor bcur;
+
     TranslationMemory *tm = GetTransMem();
 
     if (tm == NULL)
@@ -2069,9 +2049,8 @@ wxMenu *poEditFrame::GetPopupMenu(size_t item)
 #else
     menu->Append(ID_POPUP_DUMMY+0, _("References:"));
 #endif
-    menu->AppendSeparator();
     for (size_t i = 0; i < refs.GetCount(); i++)
-        menu->Append(ID_POPUP_REFS + i, _T("   ") + refs[i]);
+        menu->Append(ID_POPUP_REFS + i, _T("    ") + refs[i]);
 
 #ifdef USE_TRANSMEM
     if (GetTransMem())
@@ -2085,7 +2064,6 @@ wxMenu *poEditFrame::GetPopupMenu(size_t item)
 #else
         menu->Append(ID_POPUP_DUMMY+1, _("Automatic translations:"));
 #endif
-        menu->AppendSeparator();
 
         wxBusyCursor bcur;
         CatalogData& dt = (*m_catalog)[item];
@@ -2098,7 +2076,7 @@ wxMenu *poEditFrame::GetPopupMenu(size_t item)
                 wxString s(m_autoTranslations[i].wc_str(wxConvUTF8), wxConvLocal);
                 if (!s)
                     s = m_autoTranslations[i];
-                menu->Append(ID_POPUP_TRANS + i, _T("   ") + s);
+                menu->Append(ID_POPUP_TRANS + i, _T("    ") + s);
             }
         }
         else
@@ -2130,6 +2108,7 @@ void poEditFrame::OnAbout(wxCommandEvent&)
 
 void poEditFrame::OnHelp(wxCommandEvent&)
 {
+    InitHelp();
 #ifdef __WXMSW__
     m_help.LoadFile(m_helpBook);
 #endif
@@ -2138,6 +2117,7 @@ void poEditFrame::OnHelp(wxCommandEvent&)
 
 void poEditFrame::OnHelpGettext(wxCommandEvent&)
 {
+    InitHelp();
 #ifdef __WXMSW__
     m_help.LoadFile(m_helpBookGettext);
     m_help.DisplayContents();
@@ -2262,9 +2242,9 @@ void poEditFrame::UpdateDisplayCommentWin()
         if (m_bottomRightPanel->GetSizer() != NULL)
         {
             // need to remove and add again to ensure accurate resizing:
-            m_bottomRightPanel->GetSizer()->Remove(m_textAutoComments);
+            m_bottomRightPanel->GetSizer()->Detach(m_textAutoComments);
 
-            m_bottomRightPanel->GetSizer()->Remove(m_textComment);
+            m_bottomRightPanel->GetSizer()->Detach(m_textComment);
             m_bottomRightPanel->GetSizer()->Add(m_textAutoComments, 1, wxEXPAND);
             m_bottomRightPanel->GetSizer()->Add(m_textComment, 1, wxEXPAND);
             m_bottomRightPanel->GetSizer()->Show(m_textComment,
@@ -2295,8 +2275,7 @@ void poEditFrame::OnCommentWindowText(wxCommandEvent&)
         return;
 
     wxString comment;
-    comment = convertFromLocalCharset(
-            CommentDialog::AddStartHash(m_textComment->GetValue()));
+    comment = CommentDialog::AddStartHash(m_textComment->GetValue());
     CatalogData& data((*m_catalog)[m_list->GetIndexInCatalog(m_sel)]);
 
     wxLogTrace(_T("poedit"), _T("   comm:'%s'"), comment.c_str());
