@@ -1,5 +1,5 @@
 /*
- *  This file is part of poEdit (http://www.poedit.org)
+ *  This file is part of poEdit (http://www.poedit.net)
  *
  *  Copyright (C) 1999-2005 Vaclav Slavik
  *
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: edframe.h 1025 2006-09-01 19:29:40Z vaclavslavik $
+ *  $Id: edframe.h 1134 2007-06-23 20:29:05Z vaclavslavik $
  *
  *  Editor frame
  *
@@ -182,7 +182,9 @@ class poEditFrame : public wxFrame
         void OnAutoCommentsWinFlag(wxCommandEvent& event);
         void OnShadedListFlag(wxCommandEvent& event);
         void OnInsertOriginal(wxCommandEvent& event);
+#ifndef __WXMAC__
         void OnFullscreen(wxCommandEvent& event);
+#endif
         void OnFind(wxCommandEvent& event);
         void OnEditComment(wxCommandEvent& event);
         void OnManager(wxCommandEvent& event);
@@ -220,6 +222,7 @@ class poEditFrame : public wxFrame
 
         void RecreatePluralTextCtrls();
 
+        void InitHelp();
         wxString LoadHelpBook(const wxString& name);
 
         DECLARE_EVENT_TABLE()
@@ -247,6 +250,7 @@ class poEditFrame : public wxFrame
         wxArrayString m_autoTranslations;
 #endif
 
+        bool m_helpInitialized;
 #ifdef __WXMSW__
         wxCHMHelpController m_help;
 #else
@@ -262,7 +266,6 @@ class poEditFrame : public wxFrame
         std::vector<wxTextCtrl*> m_textTransPlural;
         wxTextCtrl *m_textTransSingularForm;
         wxNotebook *m_pluralNotebook;
-        wxGauge *m_statusGauge;
         wxStaticText *m_labelSingular, *m_labelPlural;
 #ifdef CAN_MODIFY_DEFAULT_FONT
         wxFont m_boldGuiFont;
