@@ -1,7 +1,7 @@
 /*
- *  This file is part of poEdit (http://www.poedit.org)
+ *  This file is part of poEdit (http://www.poedit.net)
  *
- *  Copyright (C) 1999-2005 Vaclav Slavik
+ *  Copyright (C) 1999-2007 Vaclav Slavik
  *  Copyright (C) 2005 Olivier Sannier
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
@@ -22,7 +22,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: edlistctrl.cpp 1045 2006-10-08 11:40:52Z vaclavslavik $
+ *  $Id: edlistctrl.cpp 1115 2007-06-16 20:42:22Z vaclavslavik $
  *
  *  List view control
  *
@@ -77,19 +77,6 @@ BEGIN_EVENT_TABLE(poEditListCtrl, wxListCtrl)
 END_EVENT_TABLE()
 
 
-static inline wxString convertToLocalCharset(const wxString& str)
-{
-#if !wxUSE_UNICODE
-    wxString s2(str.wc_str(wxConvUTF8), wxConvLocal);
-    if (s2.empty())
-        return str;
-    else
-        return s2;
-#else
-    return str;
-#endif
-}
-
 static wxBitmap AddDigit(int digit, int x, int y, const wxBitmap& bmp)
 {
     wxMemoryDC dc;
@@ -322,12 +309,12 @@ wxString poEditListCtrl::OnGetItemText(long item, long column) const
     {
         case 0:
         {
-            wxString orig = convertToLocalCharset(d.GetString());
+            wxString orig = d.GetString();
             return orig.substr(0,GetMaxColChars());
         }
         case 1:
         {
-            wxString trans = convertToLocalCharset(d.GetTranslation());
+            wxString trans = d.GetTranslation();
             return trans;
         }
         case 2:
@@ -340,10 +327,13 @@ wxString poEditListCtrl::OnGetItemText(long item, long column) const
 
 wxListItemAttr *poEditListCtrl::OnGetItemAttr(long item) const
 {
-    CatalogData& d = (*m_catalog)[m_itemIndexToCatalogIndexArray[item]];
-
     size_t idx = gs_shadedList ? size_t(item % 2) : 0;
 
+    if (m_catalog == NULL)
+        return (wxListItemAttr*)&m_attrNormal[idx];
+
+    CatalogData& d = (*m_catalog)[m_itemIndexToCatalogIndexArray[item]];
+
     if (!d.IsTranslated())
         return (wxListItemAttr*)&m_attrUntranslated[idx];
     else if (d.IsFuzzy())
@@ -356,6 +346,9 @@ wxListItemAttr *poEditListCtrl::OnGetItemAttr(long item) const
 
 int poEditListCtrl::OnGetItemImage(long item) const
 {
+    if (m_catalog == NULL)
+        return IMG_NOTHING;
+
     CatalogData& d = (*m_catalog)[m_itemIndexToCatalogIndexArray[item]];
     int index = IMG_NOTHING;
 
