@@ -1,5 +1,5 @@
 /*
- *  This file is part of poEdit (http://www.poedit.org)
+ *  This file is part of poEdit (http://www.poedit.net)
  *
  *  Copyright (C) 1999-2005 Vaclav Slavik
  *
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: fileviewer.cpp 912 2005-06-19 16:43:21Z vaclavslavik $
+ *  $Id: fileviewer.cpp 1155 2007-06-26 09:36:05Z vaclavslavik $
  *
  *  Shows part of file around specified line
  *
@@ -70,7 +70,11 @@ FileViewer::FileViewer(wxWindow *parent,
         choice->Append(references[i]);
     choice->SetSelection(startAt);
 
-    ShowReference(m_references[startAt]);
+    wxString ref(m_references[startAt]);
+    // translate windows-style paths to Unix ones, which
+    // are accepted on all platforms:
+    ref.Replace(wxT("\\"), wxT("/"));
+    ShowReference(ref);
 }
 
 void FileViewer::ShowReference(const wxString& ref)
@@ -98,12 +102,14 @@ void FileViewer::ShowReference(const wxString& ref)
     m_list->InsertColumn(0, _T("#"), wxLIST_FORMAT_RIGHT);
     m_list->InsertColumn(1, _("Line"));
 
-    wxString linestr;
     for (int i = top; i < bottom; i++)
     {
-        linestr.Printf(_T("%i  "), i);
-        m_list->InsertItem(i - top, linestr);
-        m_list->SetItem(i - top, 1, textf[i-1]);
+        wxString linenum(wxString::Format(_T("%i  "), i));
+        wxString linetxt = textf[i-1];
+        // FIXME: this is not correct
+        linetxt.Replace(_T("\t"), _T("    "));
+        m_list->InsertItem(i - top, linenum);
+        m_list->SetItem(i - top, 1, linetxt);
     }
 
     m_list->SetColumnWidth(0, wxLIST_AUTOSIZE);
@@ -129,7 +135,7 @@ FileViewer::~FileViewer()
     cfg->Write(_T("fileviewer/frame_y"), (long)pos.y);
 }
 
-/*static*/ void FileViewer::OpenInEditor(const wxString& basepath, 
+/*static*/ void FileViewer::OpenInEditor(const wxString& basepath,
                                          const wxString& reference)
 {
     wxString editor = wxConfig::Get()->Read(_T("ext_editor"), wxEmptyString);
@@ -140,8 +146,10 @@ FileViewer::~FileViewer()
     }
     wxFileName fn(reference.BeforeLast(_T(':')));
     fn.MakeAbsolute(basepath);
-    editor.Replace(_T("%f"), fn.GetFullPath());
-    editor.Replace(_T("%l"), reference.AfterLast(_T(':')));
+    editor.Replace(_T("%f"),
+                   wxString::Format(_T("\"%s\""), fn.GetFullPath().c_str()));
+    editor.Replace(_T("%l"),
+                   reference.AfterLast(_T(':')));
     wxExecute(editor);
 }
 
