@@ -1,5 +1,5 @@
 /*
- *  This file is part of poEdit (http://www.poedit.org)
+ *  This file is part of poEdit (http://www.poedit.net)
  *
  *  Copyright (C) 1999-2005 Vaclav Slavik
  *
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: isocodes.cpp 912 2005-06-19 16:43:21Z vaclavslavik $
+ *  $Id: isocodes.cpp 1080 2007-06-02 19:53:40Z vaclavslavik $
  *
  *  This file contains languages & countries names and 2-letter codes as
  *  defined by ISO 639 and ISO 3166 standards.
@@ -29,6 +29,7 @@
  */
 
 #include <wx/wxprec.h>
+#include <wx/wxchar.h>
 
 #include "isocodes.h"
 
@@ -502,22 +503,22 @@ static const wxChar *DoLookupByIso(const wxChar *iso, LanguageStruct *a)
     return NULL;
 }
 
-const wxChar *LookupLanguageCode(const wxChar *language)
+const wxChar *LookupLanguageCode(const wxString& language)
 {
-    return DoLookupByLang(language, isoLanguages);
+    return DoLookupByLang(language.c_str(), isoLanguages);
 }
 
-const wxChar *LookupCountryCode(const wxChar *country)
+const wxChar *LookupCountryCode(const wxString& country)
 {
-    return DoLookupByLang(country, isoCountries);
+    return DoLookupByLang(country.c_str(), isoCountries);
 }
 
-bool IsKnownLanguageCode(const wxChar *code)
+bool IsKnownLanguageCode(const wxString& code)
 {
-    return DoLookupByIso(code, isoLanguages) != NULL;
+    return DoLookupByIso(code.c_str(), isoLanguages) != NULL;
 }
 
-bool IsKnownCountryCode(const wxChar *code)
+bool IsKnownCountryCode(const wxString& code)
 {
-    return DoLookupByIso(code, isoCountries) != NULL;
+    return DoLookupByIso(code.c_str(), isoCountries) != NULL;
 }
