@@ -1,5 +1,5 @@
 /*
- *  This file is part of poEdit (http://www.poedit.org)
+ *  This file is part of poEdit (http://www.poedit.net)
  *
  *  Copyright (C) 1999-2005 Vaclav Slavik
  *
@@ -21,13 +21,15 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: isocodes.h 912 2005-06-19 16:43:21Z vaclavslavik $
+ *  $Id: isocodes.h 1080 2007-06-02 19:53:40Z vaclavslavik $
  *
  *  This file contains languages & countries names and 2-letter codes as
  *  defined by ISO 639 and ISO 3166 standards.
  *
  */
 
+#include <wx/string.h>
+
 struct LanguageStruct
 {
     const wxChar *iso, *lang;
@@ -36,8 +38,8 @@ struct LanguageStruct
 extern LanguageStruct isoLanguages[];
 extern LanguageStruct isoCountries[];
 
-extern const wxChar *LookupLanguageCode(const wxChar *language);
-extern const wxChar *LookupCountryCode(const wxChar *country);
+extern const wxChar *LookupLanguageCode(const wxString& language);
+extern const wxChar *LookupCountryCode(const wxString& country);
 
-extern bool IsKnownLanguageCode(const wxChar *code);
-extern bool IsKnownCountryCode(const wxChar *code);
+extern bool IsKnownLanguageCode(const wxString& code);
+extern bool IsKnownCountryCode(const wxString& code);
