@@ -1,5 +1,5 @@
 /*
- *  This file is part of poEdit (http://www.poedit.org)
+ *  This file is part of poEdit (http://www.poedit.net)
  *
  *  Copyright (C) 2000-2005 Vaclav Slavik
  *
@@ -21,14 +21,14 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: prefsdlg.cpp 999 2006-03-12 18:44:26Z vaclavslavik $
+ *  $Id: prefsdlg.cpp 1148 2007-06-24 13:42:24Z vaclavslavik $
  *
  *  Preferences settings dialog
  *
  */
 
 #include <wx/wxprec.h>
-#include "editlbox/editlbox.h"
+#include "wxeditablelistbox.h"
 #include <wx/textctrl.h>
 #include <wx/button.h>
 #include <wx/tokenzr.h>
@@ -88,6 +88,11 @@ PreferencesDialog::PreferencesDialog(wxWindow *parent)
     // remove (defunct on Unix) "Change UI language" button:
     XRCCTRL(*this, "ui_language", wxButton)->Show(false);
 #endif
+
+#if defined(__WXMSW__) || defined(__WXMAC__)
+    // FIXME
+    SetSize(GetSize().x+1,GetSize().y+1);
+#endif
 }
 
 
