@@ -1,7 +1,7 @@
 /*
- *  This file is part of poEdit (http://www.poedit.org)
+ *  This file is part of poEdit (http://www.poedit.net)
  *
- *  Copyright (C) 2001-2005 Vaclav Slavik
+ *  Copyright (C) 2001-2007 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: transmem.cpp 1031 2006-09-03 19:37:44Z vaclavslavik $
+ *  $Id: transmem.cpp 1096 2007-06-12 11:41:10Z vaclavslavik $
  *
  *  Translation memory database
  *
@@ -158,6 +158,10 @@
 
 #include DB_HEADER
 
+#if (DB_VERSION_MAJOR > 4) || (DB_VERSION_MAJOR == 4 && DB_VERSION_MINOR >= 1)
+    #define DB_OPEN_WITH_TRANSACTION
+#endif
+
 #include "transmem.h"
 
 
@@ -286,10 +290,22 @@ DbBase::DbBase(const wxString& filename, DBTYPE type)
         return;
     }
 #ifdef DB_OPEN_WITH_TRANSACTION
-    m_err = m_db->open(m_db, NULL, filename.mb_str(), NULL, type, DB_CREATE, 0);
-#else    
-    m_err = m_db->open(m_db, filename.mb_str(), NULL, type, DB_CREATE, 0);
+    m_err = m_db->open(m_db,
+                       NULL,
+                       filename.mb_str(wxConvUTF8),
+                       NULL,
+                       type,
+                       DB_CREATE,
+                       0);
+#else
+    m_err = m_db->open(m_db,
+                       filename.mb_str(wxConvUTF8),
+                       NULL,
+                       type,
+                       DB_CREATE,
+                       0);
 #endif
+
     if (m_err != 0)
     {
         LogError();
@@ -726,11 +742,11 @@ TranslationMemoriesList TranslationMemory::ms_instances;
         return NULL;
     }
     dbPath += _T('/');
-    
-    for (TranslationMemoriesList::Node *node = ms_instances.GetFirst(); 
-         node; node = node->GetNext())
+
+    for (TranslationMemoriesList::const_iterator i = ms_instances.begin();
+         i != ms_instances.end(); ++i)
     {
-        TranslationMemory *mem = node->GetData();
+        TranslationMemory *mem = *i;
         if (mem->m_lang == language && mem->m_dbPath == dbPath)
         {
             mem->m_refCnt++;
