@@ -1,5 +1,5 @@
 /*
- *  This file is part of poEdit (http://www.poedit.org)
+ *  This file is part of poEdit (http://www.poedit.net)
  *
  *  Copyright (C) 2003-2005 Vaclav Slavik
  *
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: transmemupd_wizard.cpp 912 2005-06-19 16:43:21Z vaclavslavik $
+ *  $Id: transmemupd_wizard.cpp 1111 2007-06-14 07:23:07Z vaclavslavik $
  *
  *  Translation memory database update wizard
  *
@@ -40,7 +40,7 @@
 #include <wx/filedlg.h>
 #include <wx/stattext.h>
 
-#include "editlbox/editlbox.h"
+#include "wxeditablelistbox.h"
 #include <wx/xrc/xmlres.h>
 
 #include "transmem.h"
@@ -131,7 +131,7 @@ private:
 #endif
         m_paths->SetStrings(a);
     }
-    
+
     void OnAddFiles(wxCommandEvent& event)
     {
         wxFileDialog dlg(this,
@@ -139,22 +139,26 @@ private:
                          m_defaultDir,
                          wxEmptyString,
 #ifdef __UNIX__
-                   _("Translation files (*.po;*.mo;*.rpm)|*.po;*.mo;*.rpm"), 
+                   _("Translation files (*.po;*.mo;*.rpm)|*.po;*.mo;*.rpm"),
 #else
                    _("Translation files (*.po;*.mo)|*.po;*.mo"), 
 #endif
+#if wxCHECK_VERSION(2,8,0)
+                         wxFD_OPEN | wxFD_MULTIPLE);
+#else
                          wxOPEN | wxMULTIPLE);
+#endif
         if (dlg.ShowModal() == wxID_OK)
         {
             wxArrayString f, f2;
 
             dlg.GetPaths(f);
-            
+
             m_files->GetStrings(f2);
             WX_APPEND_ARRAY(f2, f);
             m_files->SetStrings(f2);
 
-            m_defaultDir = dlg.GetDirectory();            
+            m_defaultDir = dlg.GetDirectory();
         }
     }
 
